@@ -1,6 +1,6 @@
 MVTMLEsymm1 <- function(X, nu = 1, eps = 1e-06, maxiter = 100)
     {
-    .Call( "MVTMLEsymm1", X, nu, eps, maxiter, PACKAGE = "fastM")
+    .Call( "cMVTMLEsymm1", X, nu, eps, maxiter, PACKAGE = "fastM")
     }
 
 
