@@ -1,8 +1,8 @@
 #include <RcppArmadillo.h>
 
-RcppExport SEXP MVTMLE0(SEXP x, SEXP nu, SEXP prewhitened, SEXP delta, SEXP maxiter);
-RcppExport SEXP MVTMLEsymm1(SEXP x, SEXP nu, SEXP delta, SEXP maxiter);
-RcppExport SEXP MVTMLEsymm2(SEXP x, SEXP nu, SEXP delta, SEXP maxiter);
+RcppExport SEXP cMVTMLE0(SEXP x, SEXP nu, SEXP prewhitened, SEXP delta, SEXP maxiter);
+RcppExport SEXP cMVTMLEsymm1(SEXP x, SEXP nu, SEXP delta, SEXP maxiter);
+RcppExport SEXP cMVTMLEsymm2(SEXP x, SEXP nu, SEXP delta, SEXP maxiter);
 
 RcppExport SEXP Tyler0(SEXP x, SEXP prewhitened, SEXP delta, SEXP maxiter);
 RcppExport SEXP Tylersymm1(SEXP x, SEXP delta, SEXP maxiter);
